import { Widget } from "../model/Widget";
import { WidgetPackage } from "../model/WidgetPackage";
import { WidgetParams } from "../model/WidgetParams";
import { WidgetData } from "../model/WidgetData";
import { BaseApi } from "./BaseApi";
import { HostedMode } from "../model/HostedMode";
export interface SaveWidgetOption {
    sendBroadcast?: boolean;
    id?: string;
}
interface IWidgetApi {
    registerWidgets(widgets: Widget[]): Promise<void>;
    registerWidgetPackage(widgetPackage: WidgetPackage): Promise<void>;
    getWidgets(): Promise<Widget[]>;
    addWidget(widgetName: string, hostMode: HostedMode): Promise<Widget[]>;
    getWidget(name: string): Promise<Widget>;
    getWidgetPackage(name: string): Promise<WidgetPackage>;
    getWidgetPackages(): Promise<WidgetPackage[]>;
    getWidgetUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    getWidgetPackageIndexUrl(packageName: string, hash?: boolean): Promise<string | null>;
    getWidgetConfigUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    saveDataByName<T extends WidgetData>(data: T, options: SaveWidgetOption): Promise<string>;
    getWidgetPackageUrl(packageName: string): Promise<string | null>;
}
type WidgetApiMethods = keyof IWidgetApi;
declare enum WidgetApiEvent {
    DATA_CHANGED = "event::cn.widgetjs.core.widget.data0changed",
    EDIT_DESKTOP_WIDGETS = "event::cn.widgetjs.core.widget.desktop.edit"
}
declare class WidgetApiImpl extends BaseApi<WidgetApiMethods> implements IWidgetApi {
    getChannel(): string;
    registerWidgets(widgets: Widget[]): Promise<any>;
    registerWidgetPackage(widgetPackage: WidgetPackage): Promise<any>;
    getWidgets(): Promise<Widget[]>;
    getWidgetPackages(): Promise<WidgetPackage[]>;
    /**
     *
     * @param name package name
     */
    getWidget(name: string): Promise<Widget>;
    /**
     *
     * @param name package name
     */
    getWidgetPackage(name: string): Promise<WidgetPackage>;
    /**
     * 获取组件配置地址
     * @param widgetName
     */
    getWidgetConfigUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    getWidgetUrl(widgetName: string, widgetParams: WidgetParams): Promise<string | null>;
    getWidgetPackageIndexUrl(packageName: string, hash?: boolean): Promise<string | null>;
    getWidgetPackageUrl(packageName: string): Promise<string | null>;
    /**
     * 通过组件名保存组件信息，通常用于存储可以在同类组件中共用的数据
     * @param data
     * @param options
     */
    saveDataByName<T extends WidgetData>(data: T, options?: SaveWidgetOption): Promise<string>;
    private stores;
    /**
     * 获取组件 LocalForage 存储实例
     * @param name
     */
    getStore(name: string): LocalForage;
    addWidget(widgetName: string, hostMode: HostedMode): Promise<Widget[]>;
}
declare const WidgetApi: WidgetApiImpl;
export { WidgetApi, WidgetApiEvent, WidgetApiMethods };
